@@ -23,14 +23,18 @@ app_name = st.sidebar.selectbox('AI', app_options)
 if app_name == '字段翻译':
     apps.__getattribute__(app_name)()
 
-if app_name == '数据分级预测':
-    apps.__getattribute__(app_name)()
-
-if app_name == '数据分类预测':
-    apps.__getattribute__(app_name)()
-
 elif app_name == '字段模糊匹配':
     apps.__getattribute__(app_name)()
 
+elif app_name == '数据分级预测':
+    apps.__getattribute__(app_name)()
+
+elif app_name == '数据分类预测':
+    apps.__getattribute__(app_name)()
+
 elif app_name == '爬虫工具':
     apps.__getattribute__(app_name)()
+
+# 维护人
+users = 'yuanjie@nesc.cn,liufeng@nesc.cn'.split(',')
+st.sidebar.multiselect('维护人', users, users)
