@@ -84,7 +84,7 @@ def 字段翻译():
     targets = set(st.text_area('待翻译字段', '公募基金', height=300).strip().split('\n'))
 
     if io is None:
-        io = '字段词根字典（征求意见稿）.xlsx'
+        io = '/root/model/bert/字段词根字典（征求意见稿）.xlsx'
 
     df = pd.read_excel(io)[['中文全称', '英文名称', '英文简称']]
     df['中文全称'] = df['中文全称'].str.split('/')
@@ -93,7 +93,7 @@ def 字段翻译():
     # # 自定义分割词
     # lac.add_word(' '.join(df['中文全称'].to_list())) # 有bug，没区分出
 
-    for w in set(df['中文全称'].append(pd.read_csv('words.txt', names=['w'])['w'].astype(str))):
+    for w in set(df['中文全称'].append(pd.read_csv('/root/model/bert/words.txt', names=['w'])['w'].astype(str))):
         lac.add_word(w)
 
     is_run = st.button('开始🔥')
@@ -171,6 +171,7 @@ def 字段模糊匹配():
 
         df_rst = get_rst(i2w_1, i2w_2, diss, idxs)
         df_rst.columns = ['target', 'recall', 'score']
+        download_excel(df_rst)
 
 
 @app_info()
