@@ -36,22 +36,12 @@ def clitest(path: str):
 
 @cli.command()
 @args
-def extract4ddl(ipath: str, opath=None, encoding='GB18030'):
+def extract4ddl(ipath: str, opath=None, encoding='GB18030', start_str='create table', end_str=')'):
     """解析ddl
     nesc extract4ddl '/Users/yuanjie/Desktop/notebook/0_TODO/mot_part.sql'
     """
     from nesc.extract import extract4ddl
-    extract4ddl.main(ipath, opath, encoding=encoding)
-
-
-@cli.command()
-@args
-def extract4excel(ipath: str, opath=None):
-    """解析excel
-    nesc extract4excel xx
-    """
-    from nesc.extract import extract4excel
-    extract4excel.main(ipath, opath)
+    extract4ddl.main(ipath, opath, encoding=encoding, start_str=start_str, end_str=end_str)
 
 
 @cli.command()
@@ -84,5 +74,28 @@ def text_match_v2(target, file, topn: int = 10, batch_size: int = 256,
     simv2.main(target, file, topn, batch_size, model_home)
 
 
+def _run_cmd(cmd, nohup=0):
+    cmd = f"nohup {cmd} &" if nohup else cmd
+    logger.debug(cmd)
+    return os.system(cmd)
+
+
+@cli.command()
+@args
+def run(app_file: str, app='fastapi', port=9993, nohup=0):
+    """Support fastapi/streamlit/gradio/gui app."""
+    if not Path(app_file).exists():
+        app_file = Path(get_module_path(f'../apps_{app}', __file__)) / app_file
+
+    if app in ('fastapi', 'gui', 'gradio'):
+        cmd = f"python {app_file}"
+    elif app == 'streamlit':
+        cmd = f"streamlit run {app_file} --server.baseUrlPath web --server.port {port}"
+    else:
+        cmd = "echo 无app可用"
+
+    _run_cmd(cmd, nohup)
+
+
 if __name__ == '__main__':
     cli()
